@@ -665,13 +665,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
                         )
                 else:
                     bucket = bucket_from_path
-                if TransparentPath.bucket is not None:
-                    if TransparentPath.bucket != bucket_from_path:
-                        raise ValueError(
-                            f"Bucket name {bucket_from_path} was found in your path name, but it does "
-                            f"not match the bucket name you specified for TransparentPath: {TransparentPath.bucket}"
-                        )
-                else:
+                if TransparentPath.bucket is None:
                     TransparentPath.bucket = bucket_from_path
                 path = str(path).replace("gs://", "").replace(bucket_from_path, "")
                 if path.startswith("/"):
@@ -1319,19 +1313,18 @@ class TransparentPath(os.PathLike):  # noqa : F811
         """
         self.rm(absent=absent, ignore_kind=ignore_kind, recursive=True)
 
-    def glob(self, wildcard: str = "/*", fast: bool = False) -> Iterator[TransparentPath]:
+    def glob(self, wildcard: str = "*", fast: bool = False) -> Iterator[TransparentPath]:
         """Returns a list of TransparentPath matching the wildcard pattern
 
-        By default, the wildcard is '/*'. The '/' is important if your path is a dir and you want to glob inside the
-        dir.
+        By default, the wildcard is '*'. It means 'thepath/*', so will glob in the directory.
 
         Parameters
         -----------
         wildcard: str
-            The wilcard pattern to match, relative to self (Default value = "/*")
+            The wilcard pattern to match, relative to self (Default value = "*")
 
         fast: bool
-            If True, does not check multiplicity when converting output paths to TransparentPath, significantly 
+            If True, does not check multiplicity when converting output paths to TransparentPath, significantly
             speeding up the process (Default value = False)
 
 
@@ -1344,10 +1337,13 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
         self.check_multiplicity()
 
+        if not self.is_dir(exist=True):
+            raise NotADirectoryError("The path must be a directory if you want to glob in it")
+
         if wildcard.startswith("/") or wildcard.startswith("\\"):
-            path_to_glob = (self.__path / wildcard[1:]).__fspath__()
-        else:
-            path_to_glob = self.append(wildcard).__fspath__()
+            wildcard = wildcard[1:]
+
+        path_to_glob = (self.__path / wildcard).__fspath__()
 
         if fast:
             to_ret = map(self.cast_fast, self.fs.glob(path_to_glob))
